@@ -146,11 +146,7 @@ void add_exclude_list(char *pattern,struct exclude_struct ***list, int include)
 		return;
 	}
 
-	if (!*list) {
-		*list = (struct exclude_struct **)malloc(sizeof(struct exclude_struct *)*2);
-	} else {
-		*list = (struct exclude_struct **)realloc(*list,sizeof(struct exclude_struct *)*(len+2));
-	}
+	*list = (struct exclude_struct **)Realloc(*list,sizeof(struct exclude_struct *)*(len+2));
 	
 	if (!*list || !((*list)[len] = make_exclude(pattern, include)))
 		out_of_memory("add_exclude");
